@@ -1,7 +1,7 @@
 """Módulo con el código para las pruebas
     La función print_lol imprime listas que pueden contener otras listas"""
 
-def print_lol(lista,profundidad) :
+def print_lol(lista,profundidad = 0):
     """Recorre(recursivamente) listas anidadas imprimiendo cada elemento por separado
     el argumento 'profuncidad' controla el nivel de sangrado con que se muestran los elementos"""
     for elemento in lista:
